==> hplip_3.10.6.orig.tar.gz: hplip-3.10.6/prnt/hpijs/dj970_maps2.cpp <==
/*****************************************************************************\
  dj970_maps2.cpp : Color maps for DJ970

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

APDK_BEGIN_NAMESPACE

uint32_t ulMapDJ970_Gossimer_Normal_KCMY[ 9*9*9 ]=
{
3351632640UL, 2545805056UL, 1604580608UL,  982710016UL,  646379776UL,  343603456UL,
 158529792UL,    6945024UL,    6813952UL, 3951407872UL, 2543246848UL, 1821825536UL,
 831126272UL,  343537920UL,  124843776UL,    7010048UL,    6877440UL,    6744832UL,
4116689152UL, 3446196736UL, 1835912448UL, 1097779456UL,  358863872UL,    6018304UL,
   6540544UL,    6671616UL,    6540544UL, 4114591232UL, 3947086592UL, 2706096640UL,
1246349568UL,  642302976UL,   88260864UL,    4829952UL,    5157376UL,    5486336UL,
4113345536UL, 4012686592UL, 3056777984UL, 2050081024UL,  774753024UL,  321766912UL,
   3256832UL,    3842560UL,    4103936UL, 4078807808UL, 4011636480UL, 3273701888UL,
2468656896UL, 1478476800UL,  471453696UL,  119390720UL,    2794752UL,    3315712UL,
4044531456UL, 3977294592UL, 3440555776UL, 2736304384UL, 1981330432UL, 1058195456UL,
 269210368UL,    1292544UL,    2399232UL, 4043809792UL, 4010257408UL, 3523850240UL,
2920197120UL, 2316414208UL, 1561376000UL,  755485440UL,   67163392UL,    1289728UL,
4076903680UL, 3808468480UL, 3355482880UL, 2801832704UL, 2231406080UL, 1644203776UL,
 973118720UL,  503365376UL,      52224UL, 3737164032UL, 2414321408UL, 1121105152UL,
 398182656UL,   10607872UL,    9496320UL,    8778496UL,    8189184UL,    7534336UL,
4186805760UL, 2711663104UL, 1990112000UL,  932235520UL,  259776768UL,    7268608UL,
   7200256UL,    7262976UL,    7131136UL, 4284259072UL, 3379471616UL, 2272503552UL,
1232382720UL,  476953088UL,    6603008UL,    6668544UL,    6668544UL,    6603008UL,
4181368832UL, 3544622848UL, 2588713472UL, 1515038208UL,  726378240UL,  155625728UL,
   4893184UL,    5352704UL,    5616128UL, 4146372864UL, 3643516160UL, 2838601728UL,
1983029248UL,  942842368UL,  372285696UL,    3185664UL,    3708672UL,    4102912UL,
4078215424UL, 3625492992UL, 2971507968UL, 2250283520UL, 1327471872UL,  572432640UL,
 119381248UL,    2527232UL,    3116032UL, 4077560320UL, 3591085568UL, 3071252992UL,
2417071872UL, 1712559872UL,  907058432UL,  269459456UL,    1217536UL,    2132736UL,
3909131008UL, 3489699072UL, 3104084992UL, 2533790208UL, 1980273152UL, 1225363968UL,
 621190144UL,   84188672UL,    1216512UL, 3808465920UL, 3489697792UL, 3187708160UL,
2684391424UL, 2164296704UL, 1526761984UL,  889228800UL,  436248832UL,      41472UL,
3888412160UL, 2631563008UL, 1339844864UL,  399216128UL,   12100096UL,   11121664UL,
  10141696UL,    9358592UL,    8706304UL, 4288117504UL, 3064168704UL, 1990820352UL,
 866487552UL,  194746368UL,    9742592UL,    9155328UL,    8567040UL,    7978496UL,
4283521280UL, 3295969024UL, 2122091008UL, 1283034880UL,  527473920UL,    6596864UL,
   6729984UL,    6664960UL,    6533120UL, 4281826048UL, 3309666560UL, 2538505728UL,
1548781824UL,  760188160UL,  189371392UL,    5151488UL,    5611520UL,    5678080UL,
4213410304UL, 3358230016UL, 2721155072UL, 1899202560UL,  942770944UL,  372280320UL,
   3181056UL,    3837440UL,    4297984UL, 4178808320UL, 3373696768UL, 2820442112UL,
2132706816UL, 1260291584UL,  555582720UL,  119309056UL,    2457344UL,    3047168UL,
4144468480UL, 3356133376UL, 2869659136UL, 2265809920UL, 1544454656UL,  839746048UL,
 286032640UL,    1145600UL,    1996544UL, 3724577792UL, 3288368128UL, 2902491904UL,
2415952896UL, 1795457536UL, 1090879232UL,  536904448UL,      32512UL,    1079296UL,
3623913216UL, 3271589888UL, 2952823040UL, 2550170112UL, 2046853376UL, 1409318144UL,
 855670016UL,  385908992UL,      33024UL, 4022356992UL, 2848934912UL, 1741574400UL,
 785336320UL,   96562432UL,   11963136UL,   11181056UL,   10266368UL,    9745408UL,
3952694016UL, 3047315456UL, 2124831488UL, 1118330368UL,  279145472UL,   10388224UL,
  10130432UL,    9477376UL,    8823808UL, 3698415872UL, 3094960896UL, 2306760192UL,
1317233152UL,  478374400UL,    8419328UL,    8620800UL,    8230144UL,    7575808UL,
3980742912UL, 3243072512UL, 2522111232UL, 1532650496UL,  777415680UL,  206535168UL,
   5343744UL,    5608192UL,    5673984UL, 4112867840UL, 3257688320UL, 2586796288UL,
1848993280UL,  942958336UL,  389311232UL,    3436800UL,    4030208UL,    4491264UL,
3776212736UL, 3222759424UL, 2652464384UL, 2048813056UL, 1209952000UL,  572352512UL,
 119302144UL,    2517504UL,    3175424UL, 3725097216UL, 3238620416UL, 2735302912UL,
2232314624UL, 1477339648UL,  806250496UL,  286025472UL,    1074432UL,    1925888UL,
3556800512UL, 3170921472UL, 2768267776UL, 2298505984UL, 1694526208UL, 1023436544UL,
 486565120UL,      25344UL,     942080UL, 3523246080UL, 3154144256UL, 2768267520UL,
2449501184UL, 1929407744UL, 1342204672UL,  822110208UL,  369124864UL,      25088UL,
3853987072UL, 2982686464UL, 1925853696UL, 1086862848UL,  482881792UL,   12473344UL,
  11761664UL,   11045632UL,   10327808UL, 3751359232UL, 3013686272UL, 2175154176UL,
1252473600UL,  581385472UL,   10571776UL,   10383616UL,    9994752UL,    9538816UL,
3598006528UL, 3061594880UL, 2306948352UL, 1417953024UL,  663175168UL,    8604416UL,
   8939776UL,    8944640UL,    8487936UL, 3444522240UL, 2991799808UL, 2388213760UL,
1616724224UL,  794837760UL,  157239296UL,    6774528UL,    7172608UL,    6912768UL,
3727570688UL, 3224452352UL, 2603892480UL, 1849180416UL,  943210752UL,  406407936UL,
   3626496UL,    4221696UL,    4617216UL, 3944104960UL, 3222881024UL, 2602189824UL,
1914520832UL, 1210140672UL,  555829248UL,  102779648UL,    2774528UL,    3368192UL,
3674886912UL, 3121236992UL, 2617854208UL, 2047559936UL, 1410354176UL,  789596672UL,
 252594688UL,    1199104UL,    1987072UL, 3556793856UL, 3019919872UL, 2617265408UL,
2164280320UL, 1610829824UL,  973098240UL,  453003008UL,      17664UL,     870912UL,
3405800448UL, 2969589504UL, 2583711744UL, 2248167424UL, 1845515776UL, 1224758016UL,
 788548864UL,  369117440UL,      17920UL, 3853850880UL, 3166837248UL, 2160729088UL,
1154162432UL,  634003968UL,  281551360UL,   12468992UL,   11757312UL,   11107840UL,
3751353344UL, 3013417984UL, 2242060288UL, 1302799360UL,  682108160UL,  245901568UL,
  10699008UL,   10313728UL,    9991424UL, 3547931136UL, 3061719808UL, 2307073024UL,
1502029568UL,  763963648UL,  210446848UL,    9125632UL,    9198336UL,    8874752UL,
3344049664UL, 2991990528UL, 2371627008UL, 1616849408UL,  878914048UL,  291843072UL,
   7027712UL,    7558144UL,    7430656UL, 3291884288UL, 2939562496UL, 2402888192UL,
1748839168UL, 1044458240UL,  423701760UL,    4338432UL,    5130240UL,    5461504UL,
3592299776UL, 3206424576UL, 2652908032UL, 1965239296UL, 1227173120UL,  606350080UL,
 136721408UL,    2834176UL,    3428096UL, 3876401152UL, 3188534784UL, 2668441344UL,
2014130176UL, 1309618176UL,  789721856UL,  286339840UL,    1390080UL,    2113280UL,
3640670976UL, 3036689664UL, 2566927616UL, 2046833664UL, 1409298944UL,  923022848UL,
 486749440UL,      12288UL,     931584UL, 3405793024UL, 2852142592UL, 2466265856UL,
2063612160UL, 1644181760UL, 1157643008UL,  721434880UL,  352335104UL,      12800UL,
3987999744UL, 3401780224UL, 2396064512UL, 1154878464UL,  534122240UL,  282268160UL,
 147724544UL,   12662272UL,   12212480UL, 3818458624UL, 3080457472UL, 2342653696UL,
1453723904UL,  732500736UL,  346625536UL,  111680000UL,   10827008UL,   10572288UL,
3581678080UL, 3045069056UL, 2307002624UL, 1552356096UL,  797578496UL,  294393344UL,
   9181952UL,    9450752UL,    9325824UL, 3361150464UL, 2975405056UL, 2371752960UL,
1617040896UL,  929437440UL,  359143424UL,    7150336UL,    7681280UL,    7817472UL,
3224967680UL, 2872645632UL, 2386302976UL, 1715476736UL, 1010964992UL,  507779584UL,
   4462592UL,    5385984UL,    5849088UL, 3240369152UL, 2921536256UL, 2401573376UL,
1781013248UL, 1126898432UL,  640489728UL,  153951232UL,    3352576UL,    3880448UL,
3574798336UL, 3172014080UL, 2668698112UL, 2048072448UL, 1309940736UL,  806690048UL,
 370547200UL,    1647616UL,    2174976UL, 3909426944UL, 3171098112UL, 2634029824UL,
2046827520UL, 1358961920UL,  805313536UL,  470098432UL,   67379200UL,    1058560UL,
3590335232UL, 2986354688UL, 2449483776UL, 1979721472UL, 1493182464UL, 1006642944UL,
 654321408UL,  318776832UL,       8704UL, 3987800832UL, 3619946496UL, 2714828800UL,
1507524608UL,  517931008UL,   15269888UL,   14616064UL,   14289920UL,   13314816UL,
4086891520UL, 3113877504UL, 2493448192UL, 1671757824UL,  833356800UL,  397215232UL,
 162334976UL,   95030784UL,   11413760UL, 3648980480UL, 3078684672UL, 2340487168UL,
1669857280UL,  915145984UL,  395183616UL,   93193728UL,    9506816UL,    9906688UL,
3394963456UL, 2992572160UL, 2405631488UL, 1667565056UL,  979961344UL,  443287296UL,
  74319872UL,    7738368UL,    8203264UL, 3275492352UL, 2856061440UL, 2352875520UL,
1681983488UL, 1011025920UL,  558237952UL,  122291968UL,    5444608UL,    6105344UL,
3223916800UL, 2804420096UL, 2317945600UL, 1730874112UL, 1110248192UL,  640617216UL,
 170920704UL,    3543808UL,    4006912UL, 3340243200UL, 2971012864UL, 2467696128UL,
1813449984UL, 1159269376UL,  739904512UL,  320604416UL,    1970176UL,    2497792UL,
3809020416UL, 3188197632UL, 2684815360UL, 2080836608UL, 1426525440UL,  872877568UL,
 503779072UL,  168364800UL,    1186048UL, 4143977472UL, 3238007296UL, 2650804992UL,
2080379904UL, 1526732288UL,  973084160UL,  587207680UL,  318772992UL,       5376UL,
3954376704UL, 3888250880UL, 3167879168UL, 2145189888UL,  988348416UL,  385548288UL,
  67043328UL,   16711680UL,   16711680UL, 4086824960UL, 3197632512UL, 2778791936UL,
2192244736UL, 1286864896UL,  616235008UL,  331153408UL,  213843968UL,   12386304UL,
3716153344UL, 3045064704UL, 2491613184UL, 2005532672UL, 1284505600UL,  630456320UL,
 311754752UL,  144048128UL,    9895936UL, 3412131840UL, 2975989760UL, 2422538240UL,
1852440576UL, 1215168512UL,  661782528UL,  259260416UL,    7733248UL,    8060928UL,
3225354240UL, 2856255488UL, 2369912832UL, 1766260736UL, 1145700352UL,  692912128UL,
 256901120UL,    5570560UL,    6160384UL, 3324510208UL, 2854879232UL, 2284584960UL,
1731067904UL, 1110507520UL,  674299904UL,  322174976UL,    3604480UL,    4194304UL,
3323068416UL, 2819948544UL, 2283274240UL, 1696202752UL, 1109131264UL,  723320832UL,
 371130368UL,    2162688UL,    2686976UL, 3624140800UL, 3121086464UL, 2533883904UL,
1913192448UL, 1208614912UL,  738918400UL,  470614016UL,  152109056UL,    1441792UL,
4244635648UL, 3053453312UL, 2600468480UL, 2097152000UL, 1543503872UL, 1006632960UL,
 587202560UL,  301989888UL,          0
};

APDK_END_NAMESPACE

==> hplip-3.24.4.tar.gz: hplip-3.24.4/prnt/hpijs/dj970_maps2.cpp <==
/*****************************************************************************\
  dj970_maps2.cpp : Color maps for DJ970

  Copyright (c) 1996 - 2015, HP Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of HP nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

APDK_BEGIN_NAMESPACE

uint32_t ulMapDJ970_Gossimer_Normal_KCMY[ 9*9*9 ]=
{
3351632640UL, 2545805056UL, 1604580608UL,  982710016UL,  646379776UL,  343603456UL,
 158529792UL,    6945024UL,    6813952UL, 3951407872UL, 2543246848UL, 1821825536UL,
 831126272UL,  343537920UL,  124843776UL,    7010048UL,    6877440UL,    6744832UL,
4116689152UL, 3446196736UL, 1835912448UL, 1097779456UL,  358863872UL,    6018304UL,
   6540544UL,    6671616UL,    6540544UL, 4114591232UL, 3947086592UL, 2706096640UL,
1246349568UL,  642302976UL,   88260864UL,    4829952UL,    5157376UL,    5486336UL,
4113345536UL, 4012686592UL, 3056777984UL, 2050081024UL,  774753024UL,  321766912UL,
   3256832UL,    3842560UL,    4103936UL, 4078807808UL, 4011636480UL, 3273701888UL,
2468656896UL, 1478476800UL,  471453696UL,  119390720UL,    2794752UL,    3315712UL,
4044531456UL, 3977294592UL, 3440555776UL, 2736304384UL, 1981330432UL, 1058195456UL,
 269210368UL,    1292544UL,    2399232UL, 4043809792UL, 4010257408UL, 3523850240UL,
2920197120UL, 2316414208UL, 1561376000UL,  755485440UL,   67163392UL,    1289728UL,
4076903680UL, 3808468480UL, 3355482880UL, 2801832704UL, 2231406080UL, 1644203776UL,
 973118720UL,  503365376UL,      52224UL, 3737164032UL, 2414321408UL, 1121105152UL,
 398182656UL,   10607872UL,    9496320UL,    8778496UL,    8189184UL,    7534336UL,
4186805760UL, 2711663104UL, 1990112000UL,  932235520UL,  259776768UL,    7268608UL,
   7200256UL,    7262976UL,    7131136UL, 4284259072UL, 3379471616UL, 2272503552UL,
1232382720UL,  476953088UL,    6603008UL,    6668544UL,    6668544UL,    6603008UL,
4181368832UL, 3544622848UL, 2588713472UL, 1515038208UL,  726378240UL,  155625728UL,
   4893184UL,    5352704UL,    5616128UL, 4146372864UL, 3643516160UL, 2838601728UL,
1983029248UL,  942842368UL,  372285696UL,    3185664UL,    3708672UL,    4102912UL,
4078215424UL, 3625492992UL, 2971507968UL, 2250283520UL, 1327471872UL,  572432640UL,
 119381248UL,    2527232UL,    3116032UL, 4077560320UL, 3591085568UL, 3071252992UL,
2417071872UL, 1712559872UL,  907058432UL,  269459456UL,    1217536UL,    2132736UL,
3909131008UL, 3489699072UL, 3104084992UL, 2533790208UL, 1980273152UL, 1225363968UL,
 621190144UL,   84188672UL,    1216512UL, 3808465920UL, 3489697792UL, 3187708160UL,
2684391424UL, 2164296704UL, 1526761984UL,  889228800UL,  436248832UL,      41472UL,
3888412160UL, 2631563008UL, 1339844864UL,  399216128UL,   12100096UL,   11121664UL,
  10141696UL,    9358592UL,    8706304UL, 4288117504UL, 3064168704UL, 1990820352UL,
 866487552UL,  194746368UL,    9742592UL,    9155328UL,    8567040UL,    7978496UL,
4283521280UL, 3295969024UL, 2122091008UL, 1283034880UL,  527473920UL,    6596864UL,
   6729984UL,    6664960UL,    6533120UL, 4281826048UL, 3309666560UL, 2538505728UL,
1548781824UL,  760188160UL,  189371392UL,    5151488UL,    5611520UL,    5678080UL,
4213410304UL, 3358230016UL, 2721155072UL, 1899202560UL,  942770944UL,  372280320UL,
   3181056UL,    3837440UL,    4297984UL, 4178808320UL, 3373696768UL, 2820442112UL,
2132706816UL, 1260291584UL,  555582720UL,  119309056UL,    2457344UL,    3047168UL,
4144468480UL, 3356133376UL, 2869659136UL, 2265809920UL, 1544454656UL,  839746048UL,
 286032640UL,    1145600UL,    1996544UL, 3724577792UL, 3288368128UL, 2902491904UL,
2415952896UL, 1795457536UL, 1090879232UL,  536904448UL,      32512UL,    1079296UL,
3623913216UL, 3271589888UL, 2952823040UL, 2550170112UL, 2046853376UL, 1409318144UL,
 855670016UL,  385908992UL,      33024UL, 4022356992UL, 2848934912UL, 1741574400UL,
 785336320UL,   96562432UL,   11963136UL,   11181056UL,   10266368UL,    9745408UL,
3952694016UL, 3047315456UL, 2124831488UL, 1118330368UL,  279145472UL,   10388224UL,
  10130432UL,    9477376UL,    8823808UL, 3698415872UL, 3094960896UL, 2306760192UL,
1317233152UL,  478374400UL,    8419328UL,    8620800UL,    8230144UL,    7575808UL,
3980742912UL, 3243072512UL, 2522111232UL, 1532650496UL,  777415680UL,  206535168UL,
   5343744UL,    5608192UL,    5673984UL, 4112867840UL, 3257688320UL, 2586796288UL,
1848993280UL,  942958336UL,  389311232UL,    3436800UL,    4030208UL,    4491264UL,
3776212736UL, 3222759424UL, 2652464384UL, 2048813056UL, 1209952000UL,  572352512UL,
 119302144UL,    2517504UL,    3175424UL, 3725097216UL, 3238620416UL, 2735302912UL,
2232314624UL, 1477339648UL,  806250496UL,  286025472UL,    1074432UL,    1925888UL,
3556800512UL, 3170921472UL, 2768267776UL, 2298505984UL, 1694526208UL, 1023436544UL,
 486565120UL,      25344UL,     942080UL, 3523246080UL, 3154144256UL, 2768267520UL,
2449501184UL, 1929407744UL, 1342204672UL,  822110208UL,  369124864UL,      25088UL,
3853987072UL, 2982686464UL, 1925853696UL, 1086862848UL,  482881792UL,   12473344UL,
  11761664UL,   11045632UL,   10327808UL, 3751359232UL, 3013686272UL, 2175154176UL,
1252473600UL,  581385472UL,   10571776UL,   10383616UL,    9994752UL,    9538816UL,
3598006528UL, 3061594880UL, 2306948352UL, 1417953024UL,  663175168UL,    8604416UL,
   8939776UL,    8944640UL,    8487936UL, 3444522240UL, 2991799808UL, 2388213760UL,
1616724224UL,  794837760UL,  157239296UL,    6774528UL,    7172608UL,    6912768UL,
3727570688UL, 3224452352UL, 2603892480UL, 1849180416UL,  943210752UL,  406407936UL,
   3626496UL,    4221696UL,    4617216UL, 3944104960UL, 3222881024UL, 2602189824UL,
1914520832UL, 1210140672UL,  555829248UL,  102779648UL,    2774528UL,    3368192UL,
3674886912UL, 3121236992UL, 2617854208UL, 2047559936UL, 1410354176UL,  789596672UL,
 252594688UL,    1199104UL,    1987072UL, 3556793856UL, 3019919872UL, 2617265408UL,
2164280320UL, 1610829824UL,  973098240UL,  453003008UL,      17664UL,     870912UL,
3405800448UL, 2969589504UL, 2583711744UL, 2248167424UL, 1845515776UL, 1224758016UL,
 788548864UL,  369117440UL,      17920UL, 3853850880UL, 3166837248UL, 2160729088UL,
1154162432UL,  634003968UL,  281551360UL,   12468992UL,   11757312UL,   11107840UL,
3751353344UL, 3013417984UL, 2242060288UL, 1302799360UL,  682108160UL,  245901568UL,
  10699008UL,   10313728UL,    9991424UL, 3547931136UL, 3061719808UL, 2307073024UL,
1502029568UL,  763963648UL,  210446848UL,    9125632UL,    9198336UL,    8874752UL,
3344049664UL, 2991990528UL, 2371627008UL, 1616849408UL,  878914048UL,  291843072UL,
   7027712UL,    7558144UL,    7430656UL, 3291884288UL, 2939562496UL, 2402888192UL,
1748839168UL, 1044458240UL,  423701760UL,    4338432UL,    5130240UL,    5461504UL,
3592299776UL, 3206424576UL, 2652908032UL, 1965239296UL, 1227173120UL,  606350080UL,
 136721408UL,    2834176UL,    3428096UL, 3876401152UL, 3188534784UL, 2668441344UL,
2014130176UL, 1309618176UL,  789721856UL,  286339840UL,    1390080UL,    2113280UL,
3640670976UL, 3036689664UL, 2566927616UL, 2046833664UL, 1409298944UL,  923022848UL,
 486749440UL,      12288UL,     931584UL, 3405793024UL, 2852142592UL, 2466265856UL,
2063612160UL, 1644181760UL, 1157643008UL,  721434880UL,  352335104UL,      12800UL,
3987999744UL, 3401780224UL, 2396064512UL, 1154878464UL,  534122240UL,  282268160UL,
 147724544UL,   12662272UL,   12212480UL, 3818458624UL, 3080457472UL, 2342653696UL,
1453723904UL,  732500736UL,  346625536UL,  111680000UL,   10827008UL,   10572288UL,
3581678080UL, 3045069056UL, 2307002624UL, 1552356096UL,  797578496UL,  294393344UL,
   9181952UL,    9450752UL,    9325824UL, 3361150464UL, 2975405056UL, 2371752960UL,
1617040896UL,  929437440UL,  359143424UL,    7150336UL,    7681280UL,    7817472UL,
3224967680UL, 2872645632UL, 2386302976UL, 1715476736UL, 1010964992UL,  507779584UL,
   4462592UL,    5385984UL,    5849088UL, 3240369152UL, 2921536256UL, 2401573376UL,
1781013248UL, 1126898432UL,  640489728UL,  153951232UL,    3352576UL,    3880448UL,
3574798336UL, 3172014080UL, 2668698112UL, 2048072448UL, 1309940736UL,  806690048UL,
 370547200UL,    1647616UL,    2174976UL, 3909426944UL, 3171098112UL, 2634029824UL,
2046827520UL, 1358961920UL,  805313536UL,  470098432UL,   67379200UL,    1058560UL,
3590335232UL, 2986354688UL, 2449483776UL, 1979721472UL, 1493182464UL, 1006642944UL,
 654321408UL,  318776832UL,       8704UL, 3987800832UL, 3619946496UL, 2714828800UL,
1507524608UL,  517931008UL,   15269888UL,   14616064UL,   14289920UL,   13314816UL,
4086891520UL, 3113877504UL, 2493448192UL, 1671757824UL,  833356800UL,  397215232UL,
 162334976UL,   95030784UL,   11413760UL, 3648980480UL, 3078684672UL, 2340487168UL,
1669857280UL,  915145984UL,  395183616UL,   93193728UL,    9506816UL,    9906688UL,
3394963456UL, 2992572160UL, 2405631488UL, 1667565056UL,  979961344UL,  443287296UL,
  74319872UL,    7738368UL,    8203264UL, 3275492352UL, 2856061440UL, 2352875520UL,
1681983488UL, 1011025920UL,  558237952UL,  122291968UL,    5444608UL,    6105344UL,
3223916800UL, 2804420096UL, 2317945600UL, 1730874112UL, 1110248192UL,  640617216UL,
 170920704UL,    3543808UL,    4006912UL, 3340243200UL, 2971012864UL, 2467696128UL,
1813449984UL, 1159269376UL,  739904512UL,  320604416UL,    1970176UL,    2497792UL,
3809020416UL, 3188197632UL, 2684815360UL, 2080836608UL, 1426525440UL,  872877568UL,
 503779072UL,  168364800UL,    1186048UL, 4143977472UL, 3238007296UL, 2650804992UL,
2080379904UL, 1526732288UL,  973084160UL,  587207680UL,  318772992UL,       5376UL,
3954376704UL, 3888250880UL, 3167879168UL, 2145189888UL,  988348416UL,  385548288UL,
  67043328UL,   16711680UL,   16711680UL, 4086824960UL, 3197632512UL, 2778791936UL,
2192244736UL, 1286864896UL,  616235008UL,  331153408UL,  213843968UL,   12386304UL,
3716153344UL, 3045064704UL, 2491613184UL, 2005532672UL, 1284505600UL,  630456320UL,
 311754752UL,  144048128UL,    9895936UL, 3412131840UL, 2975989760UL, 2422538240UL,
1852440576UL, 1215168512UL,  661782528UL,  259260416UL,    7733248UL,    8060928UL,
3225354240UL, 2856255488UL, 2369912832UL, 1766260736UL, 1145700352UL,  692912128UL,
 256901120UL,    5570560UL,    6160384UL, 3324510208UL, 2854879232UL, 2284584960UL,
1731067904UL, 1110507520UL,  674299904UL,  322174976UL,    3604480UL,    4194304UL,
3323068416UL, 2819948544UL, 2283274240UL, 1696202752UL, 1109131264UL,  723320832UL,
 371130368UL,    2162688UL,    2686976UL, 3624140800UL, 3121086464UL, 2533883904UL,
1913192448UL, 1208614912UL,  738918400UL,  470614016UL,  152109056UL,    1441792UL,
4244635648UL, 3053453312UL, 2600468480UL, 2097152000UL, 1543503872UL, 1006632960UL,
 587202560UL,  301989888UL,          0
};

APDK_END_NAMESPACE
